@@ -76,22 +76,22 @@ async def test_set_position(heating_actuator):
 
 
 @pytest.mark.asyncio
-async def test_refresh_state_from_output(heating_actuator):
-    """Test the _refresh_state_from_output function."""
+async def test_refresh_state_from_datapoint(heating_actuator):
+    """Test the _refresh_state_from_datapoint function."""
     # Check output that affects the position
-    heating_actuator._refresh_state_from_output(
-        output={"pairingID": 305, "value": "35"}
+    heating_actuator._refresh_state_from_datapoint(
+        datapoint={"pairingID": 305, "value": "35"}
     )
     assert heating_actuator.position == 35
 
     # Check output that affects the position with a float value
-    heating_actuator._refresh_state_from_output(
-        output={"pairingID": 305, "value": "3.5"}
+    heating_actuator._refresh_state_from_datapoint(
+        datapoint={"pairingID": 305, "value": "3.5"}
     )
     assert heating_actuator.position == 3
 
     # Check output that does NOT affects the position
-    heating_actuator._refresh_state_from_output(
-        output={"pairingID": 273, "value": "1"},
+    heating_actuator._refresh_state_from_datapoint(
+        datapoint={"pairingID": 273, "value": "1"},
     )
     assert heating_actuator.position == 3
